Personalised Learning Assistant

## About Me

#### BOTNAME

Hello I am BOTNAME, your personalised learning assistant for SUBJECTNAME. I hope to help you get the best learning experience for this subject.

CLICK HERE TO FIND OUT MORE

## I made sure I look great on any screen

1 / 2
HP
2 / 2
Tablet/Laptop
❮ ❯

## I can help you in three ways

Menu
Find A Topic
Q&A
Get Answers to Your Questions
Connect
Contact Your Tutor

## Do watch the video to learn more

Look at the demo video from one of the many other chatbots to learn how to get help from BOTNAME.

## Are you ready to start?

YES!
NO:
See the demo again

## Menu

Find A Topic

You can explore any topic in the subject.
Just select the relevant topic from the menu and explore.
Tip - if you wish to return to the main topics, type in Menu;
Otherwise you can return to the different topics by choosing either of the chips buttons.

## Q&A

Get answers to your questions

You can ask me any question and I will reply immediately / as best as I can.

Just type your question in the chat box.

## Connect

Contact Your Tutor

You can also send an email to your subject leader using this platform.
Press the down vote button and send an email enquiry.